@@ -266,6 +266,8 @@
 #include "token_info-5.26.0.h"
 #elif PERL_VERSION == 26 && PERL_SUBVERSION == 2
 #include "token_info-5.26.0.h"
+#elif PERL_VERSION == 26 && PERL_SUBVERSION == 3
+#include "token_info-5.26.0.h"
 #elif PERL_VERSION == 26
 #include "token_info-5.26.0.h"
 #elif PERL_VERSION == 27 && PERL_SUBVERSION == 0
@@ -294,11 +296,47 @@
 #include "token_info-5.27.10.h"
 #elif PERL_VERSION == 28 && PERL_SUBVERSION == 0
 #include "token_info-5.28.0.h"
+#elif PERL_VERSION == 28 && PERL_SUBVERSION == 1
+#include "token_info-5.28.0.h"
+#elif PERL_VERSION == 28 && PERL_SUBVERSION == 2
+#include "token_info-5.28.0.h"
 #elif PERL_VERSION == 28
 #include "token_info-5.28.0.h"
 #elif PERL_VERSION == 29 && PERL_SUBVERSION == 0
 #include "token_info-5.29.0.h"
-#elif PERL_VERSION > 29 || (PERL_VERSION == 29 && PERL_SUBVERSION > 0)
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 1
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 2
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 3
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 4
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 5
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 6
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 7
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 8
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 9
+#include "token_info-5.29.0.h"
+#elif PERL_VERSION == 29 && PERL_SUBVERSION == 10
+#include "token_info-5.29.10.h"
+#elif PERL_VERSION == 30 && PERL_SUBVERSION == 0
+#include "token_info-5.30.0.h"
+#elif PERL_VERSION == 30
+#include "token_info-5.30.0.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 0
+#include "token_info-5.31.0.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 1
+#include "token_info-5.31.1.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 2
+#include "token_info-5.31.2.h"
+#elif PERL_VERSION == 31 && PERL_SUBVERSION == 3
+#include "token_info-5.31.3.h"
+#elif PERL_VERSION > 31 || (PERL_VERSION == 31 && PERL_SUBVERSION > 3)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
